@@ -1,21 +1,19 @@
-import sys
 import unittest
+import sys
 
+from flaky import flaky
 import pytest
-if sys.version[0] == '2':  # Python 2
-    from IPython.core.inputsplitter import InputSplitter as TransformerManager
-else:
-    from IPython.core.inputtransformer2 import TransformerManager
+from qtpy import QtCore, QtGui, QtWidgets
+from qtpy.QtTest import QTest
 
-from qtconsole.qt import QtCore, QtGui
-from qtconsole.qt_loaders import load_qtest
 from qtconsole.console_widget import ConsoleWidget
 from qtconsole.qtconsoleapp import JupyterQtConsoleApp
 from . import no_display
 
+from IPython.core.inputtransformer2 import TransformerManager
+
 
 SHELL_TIMEOUT = 20000
-QTest = load_qtest()
 
 
 @pytest.fixture
@@ -31,6 +29,7 @@ def qtconsole(qtbot):
     return console
 
 
+@flaky(max_runs=3)
 @pytest.mark.parametrize(
     "debug", [True, False])
 def test_scroll(qtconsole, qtbot, debug):
@@ -137,6 +136,7 @@ def test_scroll(qtconsole, qtbot, debug):
     assert scroll_bar.value() > prev_position
 
 
+@flaky(max_runs=3)
 def test_input(qtconsole, qtbot):
     """
     Test input function
@@ -152,10 +152,7 @@ def test_input(qtconsole, qtbot):
     with qtbot.waitSignal(shell.executed):
         shell.execute("import time")
 
-    if sys.version[0] == '2':
-        input_function = 'raw_input'
-    else:
-        input_function = 'input'
+    input_function = 'input'
     shell.execute("print(" + input_function + "('name: ')); time.sleep(3)")
 
     qtbot.waitUntil(lambda: control.toPlainText().split()[-1] == 'name:')
@@ -172,6 +169,7 @@ def test_input(qtconsole, qtbot):
     assert 'name: test\ntest' in control.toPlainText()
 
 
+@flaky(max_runs=3)
 def test_debug(qtconsole, qtbot):
     """
     Make sure the cursor works while debugging
@@ -212,16 +210,16 @@ class TestConsoleWidget(unittest.TestCase):
     def setUpClass(cls):
         """ Create the application for the test case.
         """
-        cls._app = QtGui.QApplication.instance()
+        cls._app = QtWidgets.QApplication.instance()
         if cls._app is None:
-            cls._app = QtGui.QApplication([])
+            cls._app = QtWidgets.QApplication([])
         cls._app.setQuitOnLastWindowClosed(False)
 
     @classmethod
     def tearDownClass(cls):
         """ Exit the application.
         """
-        QtGui.QApplication.quit()
+        QtWidgets.QApplication.quit()
 
     def assert_text_equal(self, cursor, text):
         cursor.select(cursor.Document)
@@ -238,9 +236,9 @@ class TestConsoleWidget(unittest.TestCase):
                        'foo\b\nbar\n',
                        'foo\b\nbar\r\n',
                        'abc\rxyz\b\b=']
-        expected_outputs = [u'x=z\u2029',
-                            u'foo\u2029bar\u2029',
-                            u'foo\u2029bar\u2029',
+        expected_outputs = ['x=z\u2029',
+                            'foo\u2029bar\u2029',
+                            'foo\u2029bar\u2029',
                             'x=z']
         for i, text in enumerate(test_inputs):
             w._insert_plain_text(cursor, text)
@@ -260,15 +258,15 @@ class TestConsoleWidget(unittest.TestCase):
         cursor = w._get_prompt_cursor()
         w._insert_html(cursor, '<a href="http://python.org">written in</a>')
         obj = w._control
-        tip = QtGui.QToolTip
-        self.assertEqual(tip.text(), u'')
+        tip = QtWidgets.QToolTip
+        self.assertEqual(tip.text(), '')
 
         # should be somewhere else
         elsewhereEvent = QMouseEvent(MouseMove, QtCore.QPoint(50,50),
                                      noButton, noButtons, noModifiers)
         w.eventFilter(obj, elsewhereEvent)
         self.assertEqual(tip.isVisible(), False)
-        self.assertEqual(tip.text(), u'')
+        self.assertEqual(tip.text(), '')
         # should be over text
         overTextEvent = QMouseEvent(MouseMove, QtCore.QPoint(1,5),
                                     noButton, noButtons, noModifiers)
@@ -286,8 +284,8 @@ class TestConsoleWidget(unittest.TestCase):
     def test_width_height(self):
         # width()/height() QWidget properties should not be overridden.
         w = ConsoleWidget()
-        self.assertEqual(w.width(), QtGui.QWidget.width(w))
-        self.assertEqual(w.height(), QtGui.QWidget.height(w))
+        self.assertEqual(w.width(), QtWidgets.QWidget.width(w))
+        self.assertEqual(w.height(), QtWidgets.QWidget.height(w))
 
     def test_prompt_cursors(self):
         """Test the cursors that keep track of where the prompt begins and
@@ -337,6 +335,7 @@ class TestConsoleWidget(unittest.TestCase):
         w._prompt = 'prompt>'
         w._show_prompt()
         control = w._control
+        app = QtWidgets.QApplication.instance()
 
         cursor = w._get_cursor()
         w._insert_plain_text_into_buffer(cursor, "if:\n    pass")
@@ -347,21 +346,23 @@ class TestConsoleWidget(unittest.TestCase):
         # "select all" action selects cell first
         w.select_all_smart()
         QTest.keyClick(control, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier)
-        copied = QtGui.qApp.clipboard().text()
+        copied = app.clipboard().text()
         self.assertEqual(copied,  'if:\n>     pass')
 
         # # "select all" action triggered a second time selects whole document
         w.select_all_smart()
         QTest.keyClick(control, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier)
-        copied = QtGui.qApp.clipboard().text()
+        copied = app.clipboard().text()
         self.assertEqual(copied,  'Header\nprompt>if:\n>     pass')
 
+    @pytest.mark.skipif(sys.platform == 'darwin', reason="Fails on macOS")
     def test_keypresses(self):
         """Test the event handling code for keypresses."""
         w = ConsoleWidget()
         w._append_plain_text('Header\n')
         w._prompt = 'prompt>'
         w._show_prompt()
+        app = QtWidgets.QApplication.instance()
         control = w._control
 
         # Test setting the input buffer
@@ -378,21 +379,21 @@ class TestConsoleWidget(unittest.TestCase):
 
         # Ctrl+V pastes
         w._set_input_buffer('test input ')
-        QtGui.qApp.clipboard().setText('pasted text')
+        app.clipboard().setText('pasted text')
         QTest.keyClick(control, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier)
         self.assertEqual(w._get_input_buffer(), 'test input pasted text')
         self.assertEqual(control.document().blockCount(), 2)
 
         # Paste should strip indentation
         w._set_input_buffer('test input ')
-        QtGui.qApp.clipboard().setText('    pasted text')
+        app.clipboard().setText('    pasted text')
         QTest.keyClick(control, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier)
         self.assertEqual(w._get_input_buffer(), 'test input pasted text')
         self.assertEqual(control.document().blockCount(), 2)
 
         # Multiline paste, should also show continuation marks
         w._set_input_buffer('test input ')
-        QtGui.qApp.clipboard().setText('line1\nline2\nline3')
+        app.clipboard().setText('line1\nline2\nline3')
         QTest.keyClick(control, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier)
         self.assertEqual(w._get_input_buffer(),
                          'test input line1\nline2\nline3')
@@ -408,7 +409,7 @@ class TestConsoleWidget(unittest.TestCase):
         # in the case where pasted text has leading whitespace on first line
         # and we're pasting into indented position
         w._set_input_buffer('    ')
-        QtGui.qApp.clipboard().setText('    If 1:\n        pass')
+        app.clipboard().setText('    If 1:\n        pass')
         QTest.keyClick(control, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier)
         self.assertEqual(w._get_input_buffer(),
                          '    If 1:\n        pass')
@@ -420,7 +421,7 @@ class TestConsoleWidget(unittest.TestCase):
                        QtCore.Qt.ControlModifier)
         self.assertEqual(w._get_input_buffer(),
                          ("foo = ['foo', 'foo', 'foo',    \n"
-                            "       'bar', 'bar', '"))
+                          "       'bar', 'bar', '"))
         QTest.keyClick(control, QtCore.Qt.Key_Backspace,
                        QtCore.Qt.ControlModifier)
         QTest.keyClick(control, QtCore.Qt.Key_Backspace,
@@ -543,7 +544,7 @@ class TestConsoleWidget(unittest.TestCase):
         w._handle_is_complete_reply(
             dict(parent_header=dict(msg_id=msg_id),
                  content=dict(status="incomplete", indent="!!!")))
-        self.assert_text_equal(cursor, u"thing\u2029> !!!")
+        self.assert_text_equal(cursor, "thing\u2029> !!!")
         self.assertEqual(calls, [])
 
         # test complete statement (_execute called)
@@ -556,16 +557,16 @@ class TestConsoleWidget(unittest.TestCase):
                  content=dict(status="complete", indent="###")))
         self.assertEqual(calls, [("else", False)])
         calls = []
-        self.assert_text_equal(cursor, u"thing\u2029> !!!else\u2029")
+        self.assert_text_equal(cursor, "thing\u2029> !!!else\u2029")
 
         # test missing answer from is_complete
         msg_id = object()
         w.execute("done", interactive=True)
         self.assertEqual(calls, ["done"])
         calls = []
-        self.assert_text_equal(cursor, u"thing\u2029> !!!else\u2029")
+        self.assert_text_equal(cursor, "thing\u2029> !!!else\u2029")
         w._trigger_is_complete_callback()
-        self.assert_text_equal(cursor, u"thing\u2029> !!!else\u2029\u2029> ")
+        self.assert_text_equal(cursor, "thing\u2029> !!!else\u2029\u2029> ")
 
         # assert that late answer isn't destroying anything
         w._handle_is_complete_reply(
